==> apache-netbeans-java-20.0.301-sources.zip: enterprise/cloud.oracle/src/org/netbeans/modules/cloud/oracle/vault/VaultItem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.cloud.oracle.vault;

import org.netbeans.modules.cloud.oracle.items.OCID;
import org.netbeans.modules.cloud.oracle.items.OCIItem;

/**
 *
 * @author Jan Horvath
 */
public class VaultItem extends OCIItem {
    String compartmentId;
    String managementEndpoint;

    public VaultItem(OCID id, String name, String compartmentId, String managementEndpoint) {
        super(id, name);
        this.compartmentId = compartmentId;
        this.managementEndpoint = managementEndpoint;
    }

    public VaultItem() {
        super();
    }

    public String getCompartmentId() {
        return compartmentId;
    }

    public String getManagementEndpoint() {
        return managementEndpoint;
    }
    
    @Override
    public int maxInProject() {
        return Integer.MAX_VALUE;
    }
    
}

==> apache-netbeans-java-23.9.9-sources.zip: enterprise/cloud.oracle/src/org/netbeans/modules/cloud/oracle/vault/VaultItem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.cloud.oracle.vault;

import org.netbeans.modules.cloud.oracle.items.OCID;
import org.netbeans.modules.cloud.oracle.items.OCIItem;

/**
 *
 * @author Jan Horvath
 */
public class VaultItem extends OCIItem {
    private String managementEndpoint;

    public VaultItem(OCID id, String compartment, String name, String managementEndpoint, String tenancyId, String regionCode) {
        super(id, compartment, name, tenancyId, regionCode);
        this.managementEndpoint = managementEndpoint;
    }

    public VaultItem() {
        super();
    }

    public String getManagementEndpoint() {
        return managementEndpoint;
    }
    
    @Override
    public int maxInProject() {
        return 1;
    }
    
}
